==> recife-0.0.1-20210111.034625-1.jar: OSGI-OPT/src/kodkod/ast/operator/IntCompOperator.java <==
/*
 * Kodkod -- Copyright (c) 2005-present, Emina Torlak
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package kodkod.ast.operator;

/**
 * Enumerates binary comparison operators: =, < , >, <=, >=.
 */
public enum IntCompOperator {
                             /** `=' operator */
                             EQ {

                                 @Override
                                 public String toString() {
                                     return "=";
                                 }
                             },
                             /** `!=' operator */
                             NEQ {

                                 @Override
                                 public String toString() {
                                     return "!=";
                                 }
                             },
                             /** `<' operator */
                             LT {

                                 @Override
                                 public String toString() {
                                     return "<";
                                 }
                             },
                             /** `<=' operator */
                             LTE {

                                 @Override
                                 public String toString() {
                                     return "<=";
                                 }
                             },
                             /** `>' operator */
                             GT {

                                 @Override
                                 public String toString() {
                                     return ">";
                                 }
                             },
                             /** `>=' operator */
                             GTE {

                                 @Override
                                 public String toString() {
                                     return ">=";
                                 }
                             }
}

==> recife-0.0.2-20210306.205636-4.jar: OSGI-OPT/src/kodkod/ast/operator/IntCompOperator.java <==
/* 
 * Kodkod -- Copyright (c) 2005-present, Emina Torlak
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package kodkod.ast.operator;

/**
 * Enumerates binary comparison operators:  =, < , >, <=, >=.
 */
public enum IntCompOperator {
	/** `=' operator */
	EQ 	{ public String toString() { return "="; } },
	/** `!=' operator */ // [AM]
	NEQ { public String toString() { return "!="; } },
	/** `<' operator */
	LT 	{ public String toString() { return "<"; } },
	/** `<=' operator */
	LTE	{ public String toString() { return "<="; } },
	/** `>' operator */
	GT 	{ public String toString() { return ">"; } },
	/** `>=' operator */
	GTE { public String toString() { return ">="; } };
}
